==> periodic-1.0.0.tar.gz: periodic/src/PeriodicManager.php <==
<?php

namespace Drupal\periodic;

use Drupal\Component\Datetime\Time;
use Drupal\Core\State\StateInterface;

/**
 * Service for throttling tasks.
 */
class PeriodicManager {

  /**
   * The State service.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * The Time service.
   *
   * @var \Drupal\Component\Datetime\Time
   */
  protected $time;

  /**
   * Initialize Period Manager service.
   *
   * @param \Drupal\Core\State\StateInterface $state
   *   The State service.
   * @param \Drupal\Component\Datetime\Time $time
   *   The Time service.
   */
  public function __construct(StateInterface $state, Time $time) {
    $this->state = $state;
    $this->time = $time;
  }

  /**
   * Check if the interval for a task has elapsed.
   *
   * @param string $key
   *   The task key.
   * @param int $interval
   *   The interval to delay the task.
   *
   * @return bool
   *   TRUE if the task's interval has elapsed.
   */
  public function ready(string $key, int $interval): bool {
    $tasks = $this->state->get('periodic.tasks', []);

    if (!isset($tasks[$key])) {
      return TRUE;
    }
    elseif (($tasks[$key] + $interval) < $this->time->getRequestTime()) {
      return TRUE;
    }

    return FALSE;
  }

  /**
   * Update a task's status if its interval has elapsed.
   *
   * @param string $key
   *   The task key.
   * @param int $interval
   *   The interval to delay the task.
   *
   * @return bool
   *   TRUE if the task's interval has elapsed, and its period has been reset.
   */
  public function execute(string $key, int $interval): bool {
    if ($this->ready($key, $interval)) {
      $tasks = $this->state->get('periodic.tasks', []);
      $tasks[$key] = $this->time->getRequestTime();
      $this->state->set('periodic.tasks', $tasks);

      return TRUE;
    }

    return FALSE;
  }

}

==> periodic-1.0.2.tar.gz: periodic/src/PeriodicManager.php <==
<?php

namespace Drupal\periodic;

use Drupal\Component\Datetime\Time;
use Drupal\Core\State\StateInterface;

/**
 * Service for throttling tasks.
 */
class PeriodicManager {

  /**
   * The State service.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * The Time service.
   *
   * @var \Drupal\Component\Datetime\Time
   */
  protected $time;

  /**
   * Initialize Period Manager service.
   *
   * @param \Drupal\Core\State\StateInterface $state
   *   The State service.
   * @param \Drupal\Component\Datetime\Time $time
   *   The Time service.
   */
  public function __construct(StateInterface $state, Time $time) {
    $this->state = $state;
    $this->time = $time;
  }

  /**
   * Check if the interval for a task has elapsed.
   *
   * @param string $key
   *   The task key.
   * @param int $interval
   *   The interval to delay the task.
   *
   * @return bool
   *   TRUE if the task's interval has elapsed.
   */
  public function ready(string $key, int $interval): bool {
    $tasks = $this->state->get('periodic.tasks', []);

    if (!isset($tasks[$key])) {
      return TRUE;
    }
    elseif (($tasks[$key] + $interval) < $this->time->getRequestTime()) {
      return TRUE;
    }

    return FALSE;
  }

  /**
   * Update a task's status if its interval has elapsed.
   *
   * @param string $key
   *   The task key.
   * @param int $interval
   *   The interval to delay the task.
   * @param bool $first
   *   Should new tasks execute immediately.
   *
   * @return bool
   *   TRUE if the task's interval has elapsed, and its period has been reset.
   */
  public function execute(string $key, int $interval, bool $first = TRUE): bool {
    $tasks = $this->state->get('periodic.tasks', []);

    if (!$first && !isset($tasks[$key])) {
      $tasks[$key] = $this->time->getRequestTime();
      $this->state->set('periodic.tasks', $tasks);

      return FALSE;
    }
    elseif ($this->ready($key, $interval)) {
      $tasks[$key] = $this->time->getRequestTime();
      $this->state->set('periodic.tasks', $tasks);

      return TRUE;
    }

    return FALSE;
  }

  /**
   * Reset the interval for a task.
   *
   * A reset task will be ready for execution immediately.
   *
   * @param string $key
   *   The task key.
   */
  public function reset(string $key): void {
    $tasks = $this->state->get('periodic.tasks', []);
    $tasks[$key] = 0;
    $this->state->set('periodic.tasks', $tasks);
  }

  /**
   * Remove a task's data.
   *
   * @param string $key
   *   The task key.
   */
  public function remove(string $key): void {
    $tasks = $this->state->get('periodic.tasks', []);
    unset($tasks[$key]);
    $this->state->set('periodic.tasks', $tasks);
  }

}
